-- L_System.love

local gr = love.graphics
local sys = require 'L_System'

function love.load()
	screenX 			= 700
	screenY 			= 700
	centerx 			= screenX / 2	-- centers fractal on screen
	centery 			= screenY / 2
	love.window.setMode(screenX,screenY,{borderless=true})
	gr.setBackgroundColor( 50,   0, 0 )
	-- L-System path definitions
	fractal 		= {}
	fractal[1]		= {
		name       	= "Koch Curve",		-- OK
		start      	= "a",				-- see L_System.lua for definitions
		ruleA    	= "alararala",
		ruleB      	= "",
		levels       = 6,
		size 		= 500,				-- screen size of fractal
		angle		= 90				-- angle change for 'r' and 'l' movement
					}
	fractal[2] 		= {
		name       	= "dragon Curve",  -- but slow.....
		start      	= "ma",
		ruleA      	= "malmb",
		ruleB      	= "marmb",
		levels      = 14,
		size		= 400,
		angle 		= 90
					}
	fractal[3] 		= {
		name 		= "Koch Cubes",  -- ok after l added to start
		start		= "alalalal",
		ruleA		= "alararaalalara",
		ruleB		= "",
		levels		= 4,
		size		= 500,
		angle 		= 90
					}
	fractal[4] 		= {
		name 		= "Koch Cubes",  -- OK
		start		= "arararar",
		ruleA		= "aararararaa",
		ruleB		= "",
		levels		= 5,
		size 		= 500,
		angle 		= 90
					}
	fractal[5] 		= {
		name		= "Highway Dragons",  -- OK
		start		= "ma",
		ruleA		= "albml",
		ruleB		= "rmarb",
		levels		= 14,
		size		= 500,
		angle		= 90
					}
	fractal[6] 		= {
		name       	= "Sierpinski Square", --ok after adding l to start
		start      	= "mlamlmlaml",
		ruleA      	= "amrmlmramlmlamrmlmra",
		ruleB     	= "",
		levels      = 6,
		size	   	= 500,
		angle	   	= 90
					}
	fractal[7]		 = {
		name      	= "Sierpinski Triangle", -- good but rotates between levels
		start      	= "a",
		ruleA      	= "brarb",
		ruleB      	= "albla",
		levels       = 7,
		size		= 500,
		angle 		= 60
					}
	fractal[8] 		= {
		name      	= "Sierpinski Gasket", -- good
		start      	= "arrarra",
		ruleA      	= "arrarrarrbb",
		ruleB      	= "bb",
		levels		= 7,
		size		= 500,
		angle 		= 60
					}
	fractal[9]		= {
		name      	= "Snow Flake", -- good
		start      	= "arrarra",
		ruleA      	= "alarrala",
		ruleB      	= "albla",
		size        = 500,
		levels      = 5,
		angle 		= 60
					}
	fractal[10] 	= {
		name      	= "Pentigree", -- good but rotates between levels
		start      	= "arararara",
		ruleA      	= "arallalarara",
		ruleB      	= "",
		levels		= 5,
		size		= 500,
		angle 		= 72
					}
	fractal[11] 	= {
		name       	= "peano Curve",  -- ok
		start      	= "a",
		ruleA      	= "ambmalmlbmambrmrambma",
		ruleB      	= "bmambrmrambmalmlbmamb",
		levels		= 4,
		size		= 500,
		angle 		= 90
					}
	fractal[12]		= {
		name      	= "Branching",
		start      	= "rrra",
		ruleA      	= "aa[lbm][bram][rbm]",
		ruleB      	= "b[rb]",
		levels		= 6,
		size		= 500,
		angle 		= 25
					}
	fractal[13]		= {
		name      	= "Test",
		start      	= "abab",
		ruleA      	= "brbrr",
		ruleB      	= "ala",
		levels		= 10,
		size		= 500,
		angle 		= 30
					}
	selection		= 5			-- starting fractal
	nextfractal		= true
	tick, tock		= 0, 1.0	-- determines delay between levels
	end

function love.draw()
	gr.setColor( 255, 255, 0 )
	sys.showFractal( data )
	msg	= fractal[ selection ].name
	gr.print( msg, 10, 10 )
	gr.print( 'level: '..level, 10, 30 )
	gr.print( 'spacebar to change pattern', 10, 680)
	gr.setColor( 55, 45, 45 )
	gr.rectangle('line',100,100,500,500)
	end

function love.update( dt )
	if tick > tock then									-- delay & level change
		tick = 0
		if level == numlevels then leveldir = -1 end	-- step through all level (upward)
		if level == 0         then leveldir =  1 end	-- step down through levels until zero
		level = level + leveldir
		data = sys.calculateCoordinates( code[level] )
		else tick = tick + dt
		end
	if nextfractal    then					 			-- change to new fractal
		nextfractal	= false
		selection	= selection < #fractal and selection + 1 or 1
		code 		= sys.loadfractal( fractal[selection] )
		level		= 1
		data = sys.calculateCoordinates( code[level] )
		end
	end

function love.keypressed( key )
	if key == 'escape'	then love.event.push( 'quit' ) end
	if key == ' '		then nextfractal = true end
	end
